#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Photolab_bluelayer python-fu pour Gimp 2.6
# Copyright Raymond Ostertag 2009
# Licence GPL

# Version 1.0
# - initial release

# Installation : put the photolab_bluelayer.py file in your $HOME/.gimp-2.n/plug-ins.
# On Linux and Mac OSX the file must be executable.
# Documentation : http://www.gimp.org/docs/python/index.html

from gimpfu import *
import os, glob

# i18n
#
import gettext
locale_directory = gimp.locale_directory
gettext.install( "gimp20-photolab" , locale_directory, unicode=True )

#
Photolab_bluelayer_help = _("Add/remove a blue layer on top of layers. For colorblind peoples who can not see full intensity of light in blue.")                                
Photolab_bluelayer_description = Photolab_bluelayer_help
#

# constant
#
channelMixerIntensity = 2.0
layerOpacity = 50

# dialog parameters
#
Standalone_parameters = [
  (PF_IMAGE, "inImage", "Input image", None),
  (PF_DRAWABLE, "inLayer", "Input drawable", None),
]
Photolab_bluelayer_parameters = [
#put here main script parameters
]  

# main
#                                         
def python_fu_photolab_bluelayer( 
  inImage,
  inDrawable,
  ): 
  pdb.gimp_image_undo_group_start( inImage )
  #find if bluelayer allready exist
  bluelayerExist = False
  layerList = inImage.layers
  for layerID in layerList:
    if layerID.name == "ColorBlindbluelayer":
      bluelayerExist = True
      bluelayerID = layerID
  if bluelayerExist :
    #remove bluelayer
    inImage.remove_layer( bluelayerID )
  else:
    #add bluelayer
    pdb.gimp_edit_copy_visible( inImage ) 
    bluelayer = gimp.Layer( inImage, "ColorBlindbluelayer", inImage.width, inImage.height, RGBA_IMAGE, layerOpacity, ADDITION_MODE) 
    inImage.add_layer( bluelayer )
    floatingSel = pdb.gimp_edit_paste( bluelayer, False )
    pdb.gimp_floating_sel_anchor( floatingSel )
    monochrome = 0 #FALSE
    rr_gain = 0.0
    rg_gain = 0.0
    rb_gain = 0.0
    gr_gain = 0.0
    gg_gain = 0.0
    gb_gain = 0.0
    br_gain = 0.0
    bg_gain = 0.0  
    bb_gain = channelMixerIntensity
    pdb.plug_in_colors_channel_mixer( inImage, bluelayer, monochrome, rr_gain, rg_gain, rb_gain, gr_gain, gg_gain, gb_gain, br_gain, bg_gain, bb_gain )
    pdb.gimp_image_undo_group_end( inImage )

register(
  "python-fu-photolab-bluelayer",
  Photolab_bluelayer_description,
  Photolab_bluelayer_help,
  "Raymond Ostertag",
  "GPL License",
  "2009",
  _("Add/Remove blue layer"),
  "*",
  Standalone_parameters + Photolab_bluelayer_parameters,
  [],
  python_fu_photolab_bluelayer,
  menu="<Image>/Colors"+"/"+_("Colorblind tools"),
  domain=("gimp20-photolab", locale_directory)   
  )

main()
