#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Photolab_greenlayer python-fu pour Gimp 2.6
# Copyright Raymond Ostertag 2009
# Licence GPL

# Version 1.0
# - initial release

# Installation : put the photolab_greenlayer.py file in your $HOME/.gimp-2.n/plug-ins.
# On Linux and Mac OSX the file must be executable.
# Documentation : http://www.gimp.org/docs/python/index.html

from gimpfu import *
import os, glob

# i18n
#
import gettext
locale_directory = gimp.locale_directory
gettext.install( "gimp20-photolab" , locale_directory, unicode=True )

#
Photolab_greenlayer_help = _("Add/remove a green layer on top of layers. For colorblind peoples who can not see full intensity of light in green.")                                
Photolab_greenlayer_description = Photolab_greenlayer_help
#

# constant
#
channelMixerIntensity = 2.0
layerOpacity = 50

# dialog parameters
#
Standalone_parameters = [
  (PF_IMAGE, "inImage", "Input image", None),
  (PF_DRAWABLE, "inLayer", "Input drawable", None),
]
Photolab_greenlayer_parameters = [
#put here main script parameters
]  

# main
#                                         
def python_fu_photolab_greenlayer( 
  inImage,
  inDrawable,
  ): 
  pdb.gimp_image_undo_group_start( inImage )
  #find if greenlayer allready exist
  greenlayerExist = False
  layerList = inImage.layers
  for layerID in layerList:
    if layerID.name == "ColorBlindgreenlayer":
      greenlayerExist = True
      greenlayerID = layerID
  if greenlayerExist :
    #remove greenlayer
    inImage.remove_layer( greenlayerID )
  else:
    #add greenlayer
    pdb.gimp_edit_copy_visible( inImage ) 
    greenlayer = gimp.Layer( inImage, "ColorBlindgreenlayer", inImage.width, inImage.height, RGBA_IMAGE, layerOpacity, ADDITION_MODE) 
    inImage.add_layer( greenlayer )
    floatingSel = pdb.gimp_edit_paste( greenlayer, False )
    pdb.gimp_floating_sel_anchor( floatingSel )
    monochrome = 0 #FALSE
    rr_gain = 0.0
    rg_gain = 0.0
    rb_gain = 0.0
    gr_gain = 0.0
    gg_gain = channelMixerIntensity
    gb_gain = 0.0
    br_gain = 0.0
    bg_gain = 0.0  
    bb_gain = 0.0
    pdb.plug_in_colors_channel_mixer( inImage, greenlayer, monochrome, rr_gain, rg_gain, rb_gain, gr_gain, gg_gain, gb_gain, br_gain, bg_gain, bb_gain )
    pdb.gimp_image_undo_group_end( inImage )

register(
  "python-fu-photolab-greenlayer",
  Photolab_greenlayer_description,
  Photolab_greenlayer_help,
  "Raymond Ostertag",
  "GPL License",
  "2009",
  _("Add/Remove green layer"),
  "*",
  Standalone_parameters + Photolab_greenlayer_parameters,
  [],
  python_fu_photolab_greenlayer,
  menu="<Image>/Colors"+"/"+_("Colorblind tools"),
  domain=("gimp20-photolab", locale_directory)   
  )

main()
